@@ -8,6 +8,8 @@ use Socket;
 use Socket::Netlink qw( :DEFAULT );
 use Socket::Netlink::Route qw( :DEFAULT );
 
+use Data::Dump qw( pp );
+
 my $rtnlsock = IO::Socket::Netlink::Route->new
    or die "Cannot make netlink socket - $!";
 
@@ -15,9 +17,7 @@ my @messages;
 
 $rtnlsock->send_nlmsg( $rtnlsock->new_request(
       nlmsg_type  => RTM_GETROUTE,
-      nlmsg_flags => NLM_F_ROOT,
-
-      rtm_family => AF_INET,
+      nlmsg_flags => NLM_F_DUMP,
 ) );
 
 $rtnlsock->recv_nlmsgs( \@messages, 2**16 ) or
@@ -35,9 +35,8 @@ foreach my $message ( @messages ) {
       printf "  family=%d tos=%x table=%d protocol=%d scope=%d type=%d flags=%04x\n",
          $message->rtm_family, $message->rtm_tos, $message->rtm_table, $message->rtm_protocol, $message->rtm_scope, $message->rtm_type, $message->rtm_flags;
 
-      my $attrs = $message->nlattrs;
-      foreach my $name ( sort keys %$attrs ) {
-         printf "    %s => %s\n", $name, $attrs->{$name};
-      }
+      printf "  source=%s destination=%s\n", $message->src // "any", $message->dst // "any";
+
+      print pp( $message->nlattrs ) . "\n";
    }
 }
